@@ -31,12 +31,14 @@ import datetime
 import sys
 
 # this package
-from coincidence.fixtures import fixed_datetime, original_datadir, tmp_pathplus
+from coincidence.fixtures import fixed_datetime, original_datadir, path_separator, tmp_pathplus
 from coincidence.params import count, testing_boolean_values, whitespace_perms
 from coincidence.regressions import (
 		AdvancedDataRegressionFixture,
+		AdvancedFileRegressionFixture,
 		SupportsAsDict,
 		advanced_data_regression,
+		advanced_file_regression,
 		check_file_output,
 		check_file_regression
 		)
@@ -66,7 +68,7 @@ from coincidence.utils import (
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020-2021 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.1.1"
+__version__: str = "0.4.2"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["pytest_report_header", "PEP_563"]
@@ -80,7 +82,7 @@ def pytest_report_header(config, startdir):
 	return f"Test session started at {datetime.datetime.now():%H:%M:%S}"
 
 
-PEP_563: bool = (sys.version_info[:2] >= (3, 10))
+PEP_563: bool = (sys.version_info[:2] >= (3, 11))
 """
 :py:obj:`True` if the current Python version implements :pep:`563` -- Postponed Evaluation of Annotations.
 """
